pyxmpp.sasl.core.Success

Package pyxmpp :: Package sasl :: Module core :: Class Success |
[hide private]

# Class Success

source code

    Reply --+
            |
           Success

The success SASL message (sent by the server on authentication success).

Instance Methods | [hide private]
__init__(self, username, realm=None, authzid=None, data=None) Initialize the Success object. | source code
__repr__(self) | source code
Inherited from `Reply`: `base64`

Instance Variables | [hide private]
Inherited from `Reply`: `data`

Method Details | [hide private]

### __init__(self, username, realm=None, authzid=None, data=None) (Constructor) | source code
Initialize the Success object. Parameters: `username` (`unicode`) - authenticated username (authentication id). `realm` (`unicode`) - authentication realm used. `authzid` (`unicode`) - authorization id. `data` (`str`) - the success data to be sent to the client. Overrides: Reply.__init__